ice_at

Function ice_at 

pub fn ice_at(msg: &str, src_file: &SourceFile, range: SourceRange) -> !
Reports an internal compiler error, indicating a bug or mistake in the Papyri compiler. Use ice instead if the error does not correspond with any particular code in a Papyri source file.