pub fn ice_at(msg: &str, src_file: &SourceFile, range: SourceRange) -> !Expand description
Reports an internal compiler error, indicating a bug or mistake in the
Papyri compiler. Use ice instead if the error does not correspond with
any particular code in a Papyri source file.